@@ -1,11 +1,13 @@
 pub use self::{
-    charset::*, document::*, import::*, keyframe::*, layer::*, media::*, page::*, support::*,
+    charset::*, color_profile::*, document::*, import::*, keyframe::*, layer::*, media::*, page::*,
+    support::*,
 };
-use crate::{Block, Ident, SimpleBlock, Str, Url, Value};
+use crate::{Block, DashedIdent, Ident, SimpleBlock, Str, Url, Value};
 use is_macro::Is;
 use swc_common::{ast_node, Span};
 
 mod charset;
+mod color_profile;
 mod document;
 mod import;
 mod keyframe;
@@ -50,6 +52,9 @@ pub enum AtRule {
     #[tag("DocumentRule")]
     Document(DocumentRule),
 
+    #[tag("ColorProfileRule")]
+    ColorProfile(ColorProfileRule),
+
     #[tag("UnknownAtRule")]
     Unknown(UnknownAtRule),
 }
@@ -82,10 +87,19 @@ pub struct ViewportRule {
     pub block: Block,
 }
 
+#[ast_node]
+pub enum AtRuleName {
+    #[tag("DashedIdent")]
+    DashedIdent(DashedIdent),
+
+    #[tag("Ident")]
+    Ident(Ident),
+}
+
 #[ast_node("UnknownAtRule")]
 pub struct UnknownAtRule {
     pub span: Span,
-    pub name: Ident,
+    pub name: AtRuleName,
     pub prelude: Vec<Value>,
     pub block: Option<SimpleBlock>,
 }
